@@ -47,7 +47,7 @@ dirname0=`dirname $0 2>/dev/null`
 dirname0=`dirname $dirname0 2>/dev/null`
 
 case "$0" in
-  *mysql_install_db)
+  *mysqld_install_db)
     echo "$0: Deprecated program name. It will be removed in a future release, use 'mariadb-install-db' instead" 1>&2
     ;;
 esac
@@ -350,13 +350,33 @@ then
   pamtooldir="$builddir/plugin/auth_pam"
 elif test -n "$basedir"
 then
-  bindir="$basedir/@INSTALL_BINDIR@"
-  resolveip="$bindir/resolveip"
-  mysqld="$basedir/@INSTALL_SBINDIR@/mariadbd"
-  langdir="$basedir/@INSTALL_MYSQLSHAREDIR@/english"
-  srcpkgdatadir="$basedir/@INSTALL_MYSQLSHAREDIR@"
-  buildpkgdatadir="$basedir/@INSTALL_MYSQLSHAREDIR@"
-  plugindir="$basedir/@INSTALL_PLUGINDIR@"
+  bindir="$basedir/bin" # only used in the help text
+  resolveip=`find_in_dirs resolveip @resolveip_locations@`
+  if test -z "$resolveip"
+  then
+    cannot_find_file resolveip @resolveip_locations@
+    exit 1
+  fi
+  mysqld=`find_in_dirs mariadbd @mysqld_locations@`
+  if test -z "$mysqld"
+  then
+      cannot_find_file mariadbd @mysqld_locations@
+      exit 1
+  fi
+  langdir=`find_in_dirs --dir errmsg.sys @errmsg_locations@`
+  if test -z "$langdir"
+  then
+    cannot_find_file errmsg.sys @errmsg_locations@
+    exit 1
+  fi
+  srcpkgdatadir=`find_in_dirs --dir fill_help_tables.sql @pkgdata_locations@`
+  buildpkgdatadir=$srcpkgdatadir
+  if test -z "$srcpkgdatadir"
+  then
+    cannot_find_file fill_help_tables.sql @pkgdata_locations@
+    exit 1
+  fi
+  plugindir=`find_in_dirs --dir auth_pam.so $basedir/lib*/plugin $basedir/lib*/mysql/plugin $basedir/lib/*/mariadb19/plugin`
   pamtooldir=$plugindir
 # relative from where the script was run for a relocatable install
 elif test -n "$dirname0" -a -x "$rel_mysqld" -a ! "$rel_mysqld" -ef "@sbindir@/mariadbd"
@@ -382,12 +402,12 @@ fi
 
 # Set up paths to SQL scripts required for bootstrap
 fill_help_tables="$srcpkgdatadir/fill_help_tables.sql"
-create_system_tables="$srcpkgdatadir/mysql_system_tables.sql"
-create_system_tables2="$srcpkgdatadir/mysql_performance_tables.sql"
-fill_system_tables="$srcpkgdatadir/mysql_system_tables_data.sql"
+create_system_tables="$srcpkgdatadir/mariadb_system_tables.sql"
+create_system_tables2="$srcpkgdatadir/mariadb_performance_tables.sql"
+fill_system_tables="$srcpkgdatadir/mariadb_system_tables_data.sql"
 maria_add_gis_sp="$buildpkgdatadir/maria_add_gis_sp_bootstrap.sql"
-mysql_test_db="$srcpkgdatadir/mysql_test_db.sql"
-mysql_sys_schema="$buildpkgdatadir/mysql_sys_schema.sql"
+mysql_test_db="$srcpkgdatadir/mariadb_test_db.sql"
+mysql_sys_schema="$buildpkgdatadir/mariadb_sys_schema.sql"
 
 for f in "$fill_help_tables" "$create_system_tables" "$create_system_tables2" "$fill_system_tables" "$maria_add_gis_sp" "$mysql_test_db" "$mysql_sys_schema"
 do
